@@ -10,15 +10,17 @@ import sklearn.model_selection
 logger = logging.getLogger(__name__)
 
 
-def init_store(nb_channels: int,
-               nb_classes: int,
-               samplerate: Optional[float] = None,
-               make_single_class_datasets: bool = False,
-               class_names: List[str] = None,
-               class_types: List[str] = None,
-               store_type=zarr.TempStore,
-               store_name: str = 'store.zarr',
-               chunk_len: int = 1_000_000):
+def init_store(
+    nb_channels: int,
+    nb_classes: int,
+    samplerate: Optional[float] = None,
+    make_single_class_datasets: bool = False,
+    class_names: List[str] = None,
+    class_types: List[str] = None,
+    store_type=zarr.TempStore,
+    store_name: str = "store.zarr",
+    chunk_len: int = 1_000_000,
+):
     """[summary]
 
     Args:
@@ -40,57 +42,38 @@ def init_store(nb_channels: int,
         [type]: [description]
     """
 
-    if class_names is not None and nb_classes is not None and len(
-            class_names) != nb_classes:
-        raise ValueError(
-            f'Number of classes ({nb_classes}) needs to match len(class_names) ({len(class_names)}).'
-        )
-    if class_types is not None and nb_classes is not None and len(
-            class_names) != nb_classes:
-        raise ValueError(
-            f'Number of classes ({nb_classes}) needs to match len(class_names) ({len(class_types)}).'
-        )
+    if class_names is not None and nb_classes is not None and len(class_names) != nb_classes:
+        raise ValueError(f"Number of classes ({nb_classes}) needs to match len(class_names) ({len(class_names)}).")
+    if class_types is not None and nb_classes is not None and len(class_names) != nb_classes:
+        raise ValueError(f"Number of classes ({nb_classes}) needs to match len(class_names) ({len(class_types)}).")
 
     # initialize the store
     store = store_type(store_name)
     root = zarr.group(store=store, overwrite=True)  # need to def the root
-    for target in ['train', 'val', 'test']:
-        root.empty(name=f'{target}/x',
-                   shape=(0, nb_channels),
-                   chunks=(chunk_len, nb_channels),
-                   dtype=np.float16)
-        root.empty(name=f'{target}/y',
-                   shape=(0, nb_classes),
-                   chunks=(chunk_len, nb_classes),
-                   dtype=np.float16)
+    for target in ["train", "val", "test"]:
+        root.empty(name=f"{target}/x", shape=(0, nb_channels), chunks=(chunk_len, nb_channels), dtype=np.float16)
+        root.empty(name=f"{target}/y", shape=(0, nb_classes), chunks=(chunk_len, nb_classes), dtype=np.float16)
         # root.empty(name=f'{target}/eventtimes', shape=(0, nb_classes), chunks=(1_000,), dtype=np.float)
         if make_single_class_datasets:
             for class_name in class_names[1:]:
-                root.empty(name=f'{target}/y_{class_name}',
-                           shape=(0, 2),
-                           chunks=(chunk_len, nb_classes),
-                           dtype=np.float16)
+                root.empty(name=f"{target}/y_{class_name}", shape=(0, 2), chunks=(chunk_len, nb_classes), dtype=np.float16)
 
     # init metadata - since attrs cannot be appended to, we init a dict here, populate it with information below and finaly assign it to root.attrs
-    root.attrs['samplerate_x_Hz'] = samplerate
-    root.attrs['samplerate_y_Hz'] = samplerate
+    root.attrs["samplerate_x_Hz"] = samplerate
+    root.attrs["samplerate_y_Hz"] = samplerate
 
-    root.attrs['class_names'] = [str(cn) for cn in class_names]
-    root.attrs['class_types'] = class_types
+    root.attrs["class_names"] = [str(cn) for cn in class_names]
+    root.attrs["class_types"] = class_types
 
     if make_single_class_datasets:
         for class_name, class_type in zip(class_names[1:], class_types[1:]):
-            root.attrs[f'class_names_{class_name}'] = [
-                class_names[0], class_name
-            ]
-            root.attrs[f'class_types_{class_name}'] = [
-                class_types[0], class_type
-            ]
+            root.attrs[f"class_names_{class_name}"] = [class_names[0], class_name]
+            root.attrs[f"class_types_{class_name}"] = [class_types[0], class_type]
 
-    for target in ['train', 'val', 'test']:
-        root.attrs[f'filename_startsample_{target}'] = []
-        root.attrs[f'filename_endsample_{target}'] = []
-        root.attrs[f'filename_{target}'] = []
+    for target in ["train", "val", "test"]:
+        root.attrs[f"filename_startsample_{target}"] = []
+        root.attrs[f"filename_endsample_{target}"] = []
+        root.attrs[f"filename_{target}"] = []
     return root
 
 
@@ -113,14 +96,10 @@ def events_to_probabilities(eventsamples: List[int], desired_len: Optional[int]
     if desired_len is None:
         desired_len = max(eventsamples) + extent
     else:
-        eventsamples = eventsamples[
-            eventsamples < desired_len -
-            extent]  # delete all eventsamples exceeding desired_len
+        eventsamples = eventsamples[eventsamples < desired_len - extent]  # delete all eventsamples exceeding desired_len
     probabilities = np.zeros((desired_len, 2))
     probabilities[eventsamples, 1] = 1
-    probabilities[:, 1] = np.convolve(probabilities[:, 1],
-                                      np.ones((extent, )),
-                                      mode='same')
+    probabilities[:, 1] = np.convolve(probabilities[:, 1], np.ones((extent,)), mode="same")
     probabilities[:, 0] = 1 - probabilities[:, 1]
     return probabilities
 
@@ -134,25 +113,23 @@ def infer_class_info(df: pd.DataFrame):
     Returns:
         [type]: [description]
     """
-    class_names, first_indices = np.unique(df['name'], return_index=True)
+    class_names, first_indices = np.unique(df["name"], return_index=True)
     class_names = list(class_names)
-    class_names.insert(0, 'noise')
+    class_names.insert(0, "noise")
 
     # infer class type - event if start and end are the same
-    class_types = ['segment']
+    class_types = ["segment"]
     for first_index in first_indices:
-        if df.loc[first_index]['start_seconds'] == df.loc[first_index][
-                'stop_seconds']:
-            class_types.append('event')
+        if df.loc[first_index]["start_seconds"] == df.loc[first_index]["stop_seconds"]:
+            class_types.append("event")
         else:
-            class_types.append('segment')
+            class_types.append("segment")
     return class_names, class_types
 
 
-def make_annotation_matrix(df: pd.DataFrame,
-                           nb_samples: int,
-                           samplerate: float,
-                           class_names: Optional[List[str]] = None) -> np.ndarray:
+def make_annotation_matrix(
+    df: pd.DataFrame, nb_samples: int, samplerate: float, class_names: Optional[List[str]] = None
+) -> np.ndarray:
     """One-hot encode a list of song timings to a binary matrix.
 
     Args:
@@ -175,19 +152,17 @@ def make_annotation_matrix(df: pd.DataFrame,
         class_names, _ = infer_class_info(df)
     class_matrix = np.zeros((nb_samples, len(class_names)))
     for _, row in df.iterrows():
-        if not row['name'] in class_names:
+        if not row["name"] in class_names:
             continue
-        if np.all(np.isnan(row['start_seconds'])):
+        if np.all(np.isnan(row["start_seconds"])):
             continue
-        class_index = class_names.index(row['name'])
-        start_index = int(row['start_seconds'] * samplerate)
-        stop_index = int(row['stop_seconds'] * samplerate + 1)
+        class_index = class_names.index(row["name"])
+        start_index = int(row["start_seconds"] * samplerate)
+        stop_index = int(row["stop_seconds"] * samplerate + 1)
         if start_index < stop_index:
             class_matrix[start_index:stop_index, class_index] = 1
         else:
-            logger.warning(
-                f'{start_index} should be greater than {stop_index} for row {row}'
-            )
+            logger.warning(f"{start_index} should be greater than {stop_index} for row {row}")
     return class_matrix
 
 
@@ -202,17 +177,18 @@ def normalize_probabilities(p: np.ndarray) -> np.ndarray:
     """
     p_song = np.sum(p[:, 1:], axis=-1)
 
-    p[p_song > 1.0,
-      1:] = p[p_song > 1.0, 1:] / p_song[p_song > 1.0, np.newaxis]
+    p[p_song > 1.0, 1:] = p[p_song > 1.0, 1:] / p_song[p_song > 1.0, np.newaxis]
     p[:, 0] = 1 - np.sum(p[:, 1:], axis=-1)
     return p
 
 
-def make_gaps(y: np.ndarray,
-              gap_seconds: float,
-              samplerate: float,
-              start_seconds: Optional[List[float]] = None,
-              stop_seconds: Optional[List[float]] = None) -> np.ndarray:
+def make_gaps(
+    y: np.ndarray,
+    gap_seconds: float,
+    samplerate: float,
+    start_seconds: Optional[List[float]] = None,
+    stop_seconds: Optional[List[float]] = None,
+) -> np.ndarray:
     """[summary]
 
     0011112222000111100 -> 0011100222000111100 (gap_fullwidth=2)
@@ -281,21 +257,20 @@ def make_gaps(y: np.ndarray,
         for gap, gap_onset, gap_offset in zip(gaps, gap_onsets, gap_offsets):
             if gap < 2 * gap_halfwidth:
                 midpoint = int(gap_offset + gap / 2)
-                y0[midpoint - gap_halfwidth:midpoint + gap_halfwidth + 1, :] = 0
+                y0[midpoint - gap_halfwidth : midpoint + gap_halfwidth + 1, :] = 0
 
     # ensure gaps exist even when same-type segments touch
     if start_seconds is not None and stop_seconds is not None:
         start_samples = np.array(start_seconds * samplerate).astype(np.uintp)
         stop_samples = np.array(stop_seconds * samplerate).astype(np.uintp)
         for start_sample, stop_sample in zip(start_samples, stop_samples):
-            y0[start_sample:int(start_sample + gap_halfwidth), :] = 0
-            y0[int(stop_sample - gap_halfwidth):stop_sample, :] = 0
+            y0[start_sample : int(start_sample + gap_halfwidth), :] = 0
+            y0[int(stop_sample - gap_halfwidth) : stop_sample, :] = 0
 
     return y0
 
 
-def blur_events(event_trace: np.ndarray, event_std_seconds: float,
-                samplerate: float) -> np.ndarray:
+def blur_events(event_trace: np.ndarray, event_std_seconds: float, samplerate: float) -> np.ndarray:
     """Blur event trace with a gaussian.
 
     Args:
@@ -307,9 +282,6 @@ def blur_events(event_trace: np.ndarray, event_std_seconds: float,
         np.ndarray: blurred event trace
     """
     event_std_samples = event_std_seconds * samplerate
-    win = scipy.signal.gaussian(int(event_std_samples * 8),
-                                std=event_std_samples)
-    event_trace = scipy.signal.convolve(event_trace.astype(float),
-                                        win,
-                                        mode='same')
+    win = scipy.signal.gaussian(int(event_std_samples * 8), std=event_std_samples)
+    event_trace = scipy.signal.convolve(event_trace.astype(float), win, mode="same")
     return event_trace
