@@ -25,19 +25,20 @@ from typing import Any, List, Dict, Union, Optional
 
 class DictClass(dict):
     """Wrap dict in class so we can attach attrs to it."""
+
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.attrs: Dict = {}
 
     def __str__(self):
-        out = f'Data:\n'
+        out = f"Data:\n"
         for top_key in self.keys():
-            out = out + f'   {top_key}:\n'
+            out = out + f"   {top_key}:\n"
             for key, val in self[top_key].items():
-                out = out + f'      {key}: {val.shape}\n'
-        out = out + f'\nAttributes:\n'
+                out = out + f"      {key}: {val.shape}\n"
+        out = out + f"\nAttributes:\n"
         for key, val in self.attrs.items():
-            out = out + f'    {key}: {val}\n'
+            out = out + f"    {key}: {val}\n"
         return out
 
 
@@ -53,29 +54,27 @@ def load(location: str, memmap_dirs: Optional[Union[List[str], str]] = None) ->
     """
 
     if memmap_dirs is None:
-        memmap_dirs = ['train']
+        memmap_dirs = ["train"]
 
     def path_to_key(path):
         key = os.path.splitext(os.path.basename(path))[0]
         return key
 
-    dir_names = [os.path.join(location, name)
-                 for name in os.listdir(location)
-                 if os.path.isdir(os.path.join(location, name))]
+    dir_names = [os.path.join(location, name) for name in os.listdir(location) if os.path.isdir(os.path.join(location, name))]
     data = DictClass()
 
-    attrs_path = os.path.join(location, 'attrs.npy')
+    attrs_path = os.path.join(location, "attrs.npy")
     if os.path.exists(attrs_path):
         data.attrs = np.load(attrs_path, allow_pickle=True)[()]
 
     for dir_name in dir_names:
         dir_key = path_to_key(dir_name)
         data[dir_key] = dict()
-        npy_files = glob(os.path.join(dir_name, '*.npy'))
+        npy_files = glob(os.path.join(dir_name, "*.npy"))
         for npy_file in npy_files:
             npy_key = path_to_key(npy_file)
-            if memmap_dirs == 'all' or dir_key in memmap_dirs:
-                data[dir_key][npy_key] = np.lib.format.open_memmap(npy_file, 'r')
+            if memmap_dirs == "all" or dir_key in memmap_dirs:
+                data[dir_key][npy_key] = np.lib.format.open_memmap(npy_file, "r")
             else:
                 data[dir_key][npy_key] = np.load(npy_file)
     return data
@@ -89,10 +88,10 @@ def save(location: str, data: DictClass) -> None:
         data ([type]): [description]
     """
     os.makedirs(location, exist_ok=True)
-    if hasattr(data, 'attrs'):
-        np.save(os.path.join(location, 'attrs'), dict(data.attrs), allow_pickle=True)
+    if hasattr(data, "attrs"):
+        np.save(os.path.join(location, "attrs"), dict(data.attrs), allow_pickle=True)
 
     for key_top in data.keys():
         os.makedirs(os.path.join(location, key_top), exist_ok=True)
         for key, val in data[key_top].items():
-            np.save(os.path.join(location, key_top, key + '.npy'), val)
+            np.save(os.path.join(location, key_top, key + ".npy"), val)
