@@ -25,11 +25,11 @@ def normalize_pulse(pulse: np.ndarray, smooth_win: int = 15, flip_win: int = 10)
     pulse_len_half = int(pulse_len / 2)
     # center
     gwin = ss.windows.boxcar(int(smooth_win))
-    pulse_env = np.convolve(pulse**2, gwin, mode='valid')
+    pulse_env = np.convolve(pulse**2, gwin, mode="valid")
     offset = np.argmax(pulse_env) + int(np.ceil(smooth_win / 2)) + 1
-    pulse = np.pad(pulse, (len(pulse) - offset, offset), mode='constant', constant_values=0)
+    pulse = np.pad(pulse, (len(pulse) - offset, offset), mode="constant", constant_values=0)
     # flip
-    if np.sum(pulse[pulse_len - flip_win:pulse_len]) < 0:
+    if np.sum(pulse[pulse_len - flip_win : pulse_len]) < 0:
         pulse *= -1
     return pulse[pulse_len_half:-pulse_len_half]
 
@@ -53,10 +53,9 @@ def center_of_mass(x: np.ndarray, y: np.ndarray, thres: float = 0.5) -> float:
     return com
 
 
-def pulse_freq(pulse: np.ndarray,
-               fftlen: int = 1000,
-               sampling_rate: int = 10000,
-               mean_subtract: bool = True) -> Tuple[float, np.ndarray, np.ndarray]:
+def pulse_freq(
+    pulse: np.ndarray, fftlen: int = 1000, sampling_rate: int = 10000, mean_subtract: bool = True
+) -> Tuple[float, np.ndarray, np.ndarray]:
     """Calculate pulse frequency as center of mass of the pulse's amplitude spectrum.
 
     Args:
