@@ -19,7 +19,8 @@ logger = logging.getLogger(__name__)
 
 try:  # fixes cuDNN error when using LSTM layer
     import tensorflow as tf
-    physical_devices = tf.config.list_physical_devices('GPU')
+
+    physical_devices = tf.config.list_physical_devices("GPU")
     if physical_devices:
         tf.config.experimental.set_memory_growth(physical_devices[0], enable=True)
 except Exception as e:
@@ -27,17 +28,16 @@ except Exception as e:
 
 
 class TunableModel(kt.HyperModel):
-
     def __init__(self, params, tune_config=None):
         self.params = params.copy()
         self.tune_config = tune_config
         if self.tune_config is None:
             self.tune_config = {
-                'nb_filters': [4, 8, 16, 32, 64],
-                'kernel_size': [4, 8, 16, 32, 64],
-                'learning_rate': [0.01, 0.001, 0.0001],
-                'nb_hist': [128, 256, 512, 1024, 2048],
-                'nb_conv': [1, 2, 3, 4, 6, 8]
+                "nb_filters": [4, 8, 16, 32, 64],
+                "kernel_size": [4, 8, 16, 32, 64],
+                "learning_rate": [0.01, 0.001, 0.0001],
+                "nb_hist": [128, 256, 512, 1024, 2048],
+                "nb_conv": [1, 2, 3, 4, 6, 8],
             }
 
     def build(self, hp):
@@ -45,28 +45,29 @@ class TunableModel(kt.HyperModel):
             hp.Choice(name, values=values)
 
         self.params.update(hp.values)
-        model = models.model_dict[self.params['model_name']](**self.params)
+        model = models.model_dict[self.params["model_name"]](**self.params)
         return model
 
 
 class DasTuner(kt.Tuner):
-
     def __init__(self, params, *args, tracker=None, **kwargs):
         self.params = params.copy()
         self.tracker = tracker
         super().__init__(*args, **kwargs)
 
-    def run_trial(self,
-                  trial,
-                  train_x,
-                  train_y,
-                  val_x,
-                  val_y,
-                  epochs=10,
-                  steps_per_epoch=None,
-                  verbose=1,
-                  class_weight=None,
-                  callbacks=None):
+    def run_trial(
+        self,
+        trial,
+        train_x,
+        train_y,
+        val_x,
+        val_y,
+        epochs=10,
+        steps_per_epoch=None,
+        verbose=1,
+        class_weight=None,
+        callbacks=None,
+    ):
         try:
             if callbacks is None:
                 callbacks = []
@@ -75,18 +76,20 @@ class DasTuner(kt.Tuner):
             self.current_trial = trial
 
             # these need updating based on current hyperparameters
-            self.params['stride'] = self.params['nb_hist']
-            if self.params['ignore_boundaries']:
+            self.params["stride"] = self.params["nb_hist"]
+            if self.params["ignore_boundaries"]:
                 # this does not completely avoid boundary effects but should minimize them sufficiently
-                self.params['data_padding'] = int(np.ceil(self.params['kernel_size'] * self.params['nb_conv']))
-                self.params['stride'] = self.params['stride'] - 2 * self.params['data_padding']
+                self.params["data_padding"] = int(np.ceil(self.params["kernel_size"] * self.params["nb_conv"]))
+                self.params["stride"] = self.params["stride"] - 2 * self.params["data_padding"]
 
-            data_gen = data.AudioSequence(train_x,
-                                          train_y,
-                                          shuffle=True,
-                                          nb_repeats=1,
-                                          last_sample=train_x.shape[0] - 2 * self.params['nb_hist'],
-                                          **self.params)
+            data_gen = data.AudioSequence(
+                train_x,
+                train_y,
+                shuffle=True,
+                nb_repeats=1,
+                last_sample=train_x.shape[0] - 2 * self.params["nb_hist"],
+                **self.params,
+            )
             val_gen = data.AudioSequence(val_x, val_y, shuffle=False, **self.params)
             logger.info("Data:")
             logger.info(f"training: {data_gen}")
@@ -101,65 +104,69 @@ class DasTuner(kt.Tuner):
                 self.tracker.reinit(self.params)
             model = self.hypermodel.build(trial.hyperparameters)
             model.params = self.params  # attach params to model so we can save them in ModelParamsCheckpoint
-            fit_hist = model.fit(data_gen,
-                                 validation_data=val_gen,
-                                 epochs=epochs,
-                                 steps_per_epoch=steps_per_epoch,
-                                 callbacks=callbacks,
-                                 verbose=verbose)
+            fit_hist = model.fit(
+                data_gen,
+                validation_data=val_gen,
+                epochs=epochs,
+                steps_per_epoch=steps_per_epoch,
+                callbacks=callbacks,
+                verbose=verbose,
+            )
             return fit_hist
         except KeyboardInterrupt:
-            logger.exception('Interrupted')
+            logger.exception("Interrupted")
             sys.exit(0)
         except:
             logger.exception("Something went wrong. Will try to continue.")
-            self.current_trial.status = 'INVALID'
+            self.current_trial.status = "INVALID"
 
 
-def train(*,
-          data_dir: str,
-          x_suffix: str = '',
-          y_suffix: str = '',
-          save_dir: str = './',
-          save_prefix: Optional[str] = None,
-          save_name: Optional[str] = None,
-          model_name: str = 'tcn',
-          nb_filters: int = 16,
-          kernel_size: int = 16,
-          nb_conv: int = 3,
-          use_separable: List[bool] = False,
-          nb_hist: int = 1024,
-          ignore_boundaries: bool = True,
-          batch_norm: bool = True,
-          nb_pre_conv: int = 0,
-          pre_nb_dft: int = 64,
-          pre_kernel_size: int = 3,
-          pre_nb_filters: int = 16,
-          upsample: bool = True,
-          dilations: Optional[List[int]] = None,
-          nb_lstm_units: int = 0,
-          verbose: int = 2,
-          batch_size: int = 32,
-          nb_epoch: int = 400,
-          learning_rate: Optional[float] = None,
-          reduce_lr: bool = False,
-          reduce_lr_patience: int = 5,
-          fraction_data: Optional[float] = None,
-          seed: Optional[int] = None,
-          batch_level_subsampling: bool = False,
-          augmentations: Optional[str] = None,
-          tensorboard: bool = False,
-          wandb_api_token: Optional[str] = None,
-          wandb_project: Optional[str] = None,
-          wandb_entity: Optional[str] = None,
-          log_messages: bool = False,
-          nb_stacks: int = 2,
-          with_y_hist: bool = True,
-          balance: bool = False,
-          version_data: bool = True,
-          tune_config: Optional[str] = None,
-          nb_tune_trials: int = 1_000,
-          _qt_progress: bool = False) -> Tuple[keras.Model, Dict[str, Any]]:
+def train(
+    *,
+    data_dir: str,
+    x_suffix: str = "",
+    y_suffix: str = "",
+    save_dir: str = "./",
+    save_prefix: Optional[str] = None,
+    save_name: Optional[str] = None,
+    model_name: str = "tcn",
+    nb_filters: int = 16,
+    kernel_size: int = 16,
+    nb_conv: int = 3,
+    use_separable: List[bool] = False,
+    nb_hist: int = 1024,
+    ignore_boundaries: bool = True,
+    batch_norm: bool = True,
+    nb_pre_conv: int = 0,
+    pre_nb_dft: int = 64,
+    pre_kernel_size: int = 3,
+    pre_nb_filters: int = 16,
+    upsample: bool = True,
+    dilations: Optional[List[int]] = None,
+    nb_lstm_units: int = 0,
+    verbose: int = 2,
+    batch_size: int = 32,
+    nb_epoch: int = 400,
+    learning_rate: Optional[float] = None,
+    reduce_lr: bool = False,
+    reduce_lr_patience: int = 5,
+    fraction_data: Optional[float] = None,
+    seed: Optional[int] = None,
+    batch_level_subsampling: bool = False,
+    augmentations: Optional[str] = None,
+    tensorboard: bool = False,
+    wandb_api_token: Optional[str] = None,
+    wandb_project: Optional[str] = None,
+    wandb_entity: Optional[str] = None,
+    log_messages: bool = False,
+    nb_stacks: int = 2,
+    with_y_hist: bool = True,
+    balance: bool = False,
+    version_data: bool = True,
+    tune_config: Optional[str] = None,
+    nb_tune_trials: int = 1_000,
+    _qt_progress: bool = False,
+) -> Tuple[keras.Model, Dict[str, Any]]:
     """Tune the hyperparameters of a DAS network.
 
     Args:
@@ -279,10 +286,11 @@ def train(*,
         return_sequences = True
         stride = nb_hist
         y_offset = 0
-        sample_weight_mode = 'temporal'
+        sample_weight_mode = "temporal"
         if ignore_boundaries:
-            data_padding = int(np.ceil(
-                kernel_size * nb_conv))  # this does not completely avoid boundary effects but should minimize them sufficiently
+            data_padding = int(
+                np.ceil(kernel_size * nb_conv)
+            )  # this does not completely avoid boundary effects but should minimize them sufficiently
             stride = stride - 2 * data_padding
     else:  # classification
         return_sequences = False
@@ -291,7 +299,7 @@ def train(*,
 
     if stride <= 0:
         raise ValueError(
-            'Stride <=0 - needs to be >0. Possible solutions: reduce kernel_size, increase nb_hist parameters, uncheck ignore_boundaries'
+            "Stride <=0 - needs to be >0. Possible solutions: reduce kernel_size, increase nb_hist parameters, uncheck ignore_boundaries"
         )
 
     if not upsample:
@@ -300,12 +308,12 @@ def train(*,
         output_stride = 1  # since we upsample output to original sampling rate. w/o upsampling: `output_stride = int(2**nb_pre_conv)` since each pre-conv layer does 2x max pooling
 
     if save_prefix is None:
-        save_prefix = ''
+        save_prefix = ""
 
     if len(save_prefix):
-        save_prefix = save_prefix + '_'
+        save_prefix = save_prefix + "_"
     params = locals()
-    del params['_qt_progress']
+    del params["_qt_progress"]
 
     if tune_config is not None:
         with open(tune_config, "r") as stream:
@@ -316,26 +324,26 @@ def train(*,
 
     if stride <= 0:
         raise ValueError(
-            'Stride <=0 - needs to be >0. Possible solutions: reduce kernel_size, increase nb_hist parameters, uncheck ignore_boundaries'
+            "Stride <=0 - needs to be >0. Possible solutions: reduce kernel_size, increase nb_hist parameters, uncheck ignore_boundaries"
         )
 
     # remove learning rate param if not set so the value from the model def is used
-    if params['learning_rate'] is None:
-        del params['learning_rate']
+    if params["learning_rate"] is None:
+        del params["learning_rate"]
 
-    if '_multi' in model_name:
-        params['unpack_channels'] = True
+    if "_multi" in model_name:
+        params["unpack_channels"] = True
 
-    logger.info(f'Loading data from {data_dir}.')
+    logger.info(f"Loading data from {data_dir}.")
     d = io.load(data_dir, x_suffix=x_suffix, y_suffix=y_suffix)
     # FIXME throw error if no `val` in `d``
-    if 'val' not in d:
-        logging.error('No validation data found.')
-        raise ValueError('No validation data found.')
+    if "val" not in d:
+        logging.error("No validation data found.")
+        raise ValueError("No validation data found.")
     params.update(d.attrs)  # add metadata from data.attrs to params for saving
 
     if version_data:
-        params['data_hash'] = data_hash.hash_data(data_dir)
+        params["data_hash"] = data_hash.hash_data(data_dir)
         logger.info(f"Version of the data:")
         logger.info(f"   MD5 hash of {data_dir} is")
         logger.info(f"   {params['data_hash']}")
@@ -345,60 +353,61 @@ def train(*,
             logger.info(
                 f"{fraction_data} seconds corresponds to {fraction_data / (d['train']['x'].shape[0] / d.attrs['samplerate_x_Hz']):1.4f} of the training data."
             )
-            fraction_data = np.min((fraction_data / (d['train']['x'].shape[0] / d.attrs['samplerate_x_Hz']), 1.0))
+            fraction_data = np.min((fraction_data / (d["train"]["x"].shape[0] / d.attrs["samplerate_x_Hz"]), 1.0))
         elif fraction_data < 1.0:
             logger.info(f"Using {fraction_data:1.4f} of the training and validation data.")
 
     if fraction_data is not None and not batch_level_subsampling and fraction_data != 1.0:  # train on a subset
         min_nb_samples = nb_hist * (batch_size + 2)  # ensure the generator contains at least one full batch
-        first_sample_train, last_sample_train = data.sub_range(d['train']['x'].shape[0],
-                                                               fraction_data,
-                                                               min_nb_samples,
-                                                               seed=seed)
-        first_sample_val, last_sample_val = data.sub_range(d['val']['x'].shape[0], fraction_data, min_nb_samples, seed=seed)
+        first_sample_train, last_sample_train = data.sub_range(
+            d["train"]["x"].shape[0], fraction_data, min_nb_samples, seed=seed
+        )
+        first_sample_val, last_sample_val = data.sub_range(d["val"]["x"].shape[0], fraction_data, min_nb_samples, seed=seed)
     else:
         first_sample_train, last_sample_train = 0, None
         first_sample_val, last_sample_val = 0, None
 
     # TODO clarify nb_channels, nb_freq semantics - always [nb_samples,..., nb_channels] -  nb_freq is ill-defined for 2D data
-    params.update({
-        'nb_freq': d['train']['x'].shape[1],
-        'nb_channels': d['train']['x'].shape[-1],
-        'nb_classes': len(params['class_names']),
-        'first_sample_train': first_sample_train,
-        'last_sample_train': last_sample_train,
-        'first_sample_val': first_sample_val,
-        'last_sample_val': last_sample_val,
-    })
-    logger.info('Parameters:')
+    params.update(
+        {
+            "nb_freq": d["train"]["x"].shape[1],
+            "nb_channels": d["train"]["x"].shape[-1],
+            "nb_classes": len(params["class_names"]),
+            "first_sample_train": first_sample_train,
+            "last_sample_train": last_sample_train,
+            "first_sample_val": first_sample_val,
+            "last_sample_val": last_sample_val,
+        }
+    )
+    logger.info("Parameters:")
     logger.info(params)
 
-    logger.info('Preparing data')
+    logger.info("Preparing data")
     if fraction_data is not None and batch_level_subsampling:  # train on a subset
         np.random.seed(seed)
         shuffle_subset = fraction_data
     else:
         shuffle_subset = None
 
-    params['class_weights'] = None
+    params["class_weights"] = None
     if balance:
         logger.info("Balancing classes:")
         logger.info("   Computing class weights.")
-        params['class_weights'] = data.compute_class_weights(d['train']['y'][first_sample_train:last_sample_train])
+        params["class_weights"] = data.compute_class_weights(d["train"]["y"][first_sample_train:last_sample_train])
         logger.info(f"   {params['class_weights']}")
 
-    logger.info('Building network')
+    logger.info("Building network")
 
     os.makedirs(os.path.abspath(save_dir), exist_ok=True)
     if save_name is None:
-        save_name = time.strftime('%Y%m%d_%H%M%S')
-    save_name = '{0}/{1}{2}'.format(save_dir, save_prefix, save_name)
-    params['save_name'] = save_name
+        save_name = time.strftime("%Y%m%d_%H%M%S")
+    save_name = "{0}/{1}{2}".format(save_dir, save_prefix, save_name)
+    params["save_name"] = save_name
 
-    logger.info(f'Will save to {save_name}.')
+    logger.info(f"Will save to {save_name}.")
 
     # setup callbacks
-    callbacks = [EarlyStopping(monitor='val_loss', patience=15)]
+    callbacks = [EarlyStopping(monitor="val_loss", patience=15)]
 
     if reduce_lr:
         callbacks.append(ReduceLROnPlateau(patience=reduce_lr_patience, verbose=1))
@@ -410,7 +419,7 @@ def train(*,
         callbacks.append(TensorBoard(log_dir=save_name))
 
     if wandb_api_token and wandb_project:  # could also get those from env vars!
-        del params['wandb_api_token']
+        del params["wandb_api_token"]
         wandb = tracking.Wandb(wandb_project, wandb_api_token, wandb_entity, params)
         if wandb:
             callbacks.append(wandb.callback())
@@ -434,16 +443,16 @@ def train(*,
     utils.save_params(params, save_name)
 
     # TRAIN NETWORK
-    logger.info('Start hyperparameter tuning')
+    logger.info("Start hyperparameter tuning")
     tuner.search(
-        train_x=d['train']['x'],
-        train_y=d['train']['y'],
-        val_x=d['val']['x'],
-        val_y=d['val']['y'],
+        train_x=d["train"]["x"],
+        train_y=d["train"]["y"],
+        val_x=d["val"]["x"],
+        val_y=d["val"]["y"],
         epochs=nb_epoch,
         verbose=verbose,
         callbacks=callbacks,
-        class_weight=params['class_weights'],
+        class_weight=params["class_weights"],
     )
     logger.info(tuner.results_summary())
 
@@ -452,28 +461,28 @@ def train(*,
     params.update(best_hp)
 
     logger.info(f"   Saving best params and model to {params['save_name']}.")
-    utils.save_params(params, params['save_name'])
-    model = models.model_dict[params['model_name']](**params)
-    model.save(params['save_name'] + '_model.h5')
+    utils.save_params(params, params["save_name"])
+    model = models.model_dict[params["model_name"]](**params)
+    model.save(params["save_name"] + "_model.h5")
 
     # TEST
-    if 'test' not in d or len(d['test']['x']) < nb_hist:
-        logger.info('   No test data - skipping final evaluation step.')
+    if "test" not in d or len(d["test"]["x"]) < nb_hist:
+        logger.info("   No test data - skipping final evaluation step.")
     else:
         logger.info(f"   Re-loading last best model from {params['save_name']}.")
 
-        logger.info('   Predicting')
-        x_test, y_test, y_pred = evaluate.evaluate_probabilities(x=d['test']['x'], y=d['test']['y'], model=model, params=params)
+        logger.info("   Predicting")
+        x_test, y_test, y_pred = evaluate.evaluate_probabilities(x=d["test"]["x"], y=d["test"]["y"], model=model, params=params)
 
         labels_test = predict.labels_from_probabilities(y_test)
         labels_pred = predict.labels_from_probabilities(y_pred)
 
-        logger.info('   Evaluating')
-        conf_mat, report = evaluate.evaluate_segments(labels_test, labels_pred, params['class_names'], report_as_dict=True)
+        logger.info("   Evaluating")
+        conf_mat, report = evaluate.evaluate_segments(labels_test, labels_pred, params["class_names"], report_as_dict=True)
         logger.info(conf_mat)
         logger.info(report)
-        params['conf_mat'] = conf_mat.tolist()
-        params['report'] = report
+        params["conf_mat"] = conf_mat.tolist()
+        params["report"] = report
         logger.info(f'   Updating params file "{save_name}_params.yaml" with the test results.')
         utils.save_params(params, save_name)
 
@@ -481,19 +490,19 @@ def train(*,
             wandb.log_test_results(report)
 
         save_filename = "{0}_results.h5".format(save_name)
-        logger.info('   Saving to ' + save_filename + '.')
+        logger.info("   Saving to " + save_filename + ".")
         ddd = {
-            'fit_hist': [],
-            'confusion_matrix': conf_mat,
-            'classification_report': report,
-            'x_test': x_test,
-            'y_test': y_test,
-            'y_pred': y_pred,
-            'labels_test': labels_test,
-            'labels_pred': np.array(labels_pred),
-            'params': params,
+            "fit_hist": [],
+            "confusion_matrix": conf_mat,
+            "classification_report": report,
+            "x_test": x_test,
+            "y_test": y_test,
+            "y_pred": y_pred,
+            "labels_test": labels_test,
+            "labels_pred": np.array(labels_pred),
+            "params": params,
         }
         fl.save(save_filename, ddd)
 
-    logger.info('DONE.')
+    logger.info("DONE.")
     return model, params, tuner
